==> moengagesdk-4.1.00-sources.jar: com/moengage/push/hms/puskit/PushKitManager.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 * All rights reserved.
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.push.hms.puskit;

import android.content.Context;
import com.moengage.core.Logger;

/**
 * @author Umang Chamaria
 * Date: 08/04/20
 */
public class PushKitManager {

  private static final String TAG = "PushKitManager";

  PushKitHandler handler;

  private PushKitManager() {
    loadHandler();
  }

  private static PushKitManager instance;

  public static PushKitManager getInstance() {
    if (instance == null) {
      synchronized (PushKitManager.class) {
        if (instance == null) instance = new PushKitManager();
      }
    }
    return instance;
  }

  private void loadHandler() {
    try {
      Class clazz = Class.forName("com.moengage.hms.pushkit.PushKitHandlerImpl");
      handler = (PushKitHandler) clazz.newInstance();
    } catch (Exception e) {
      Logger.e(TAG + " PushKit module not present.");
    }
  }

  public void onAppOpen(Context context) {
    if (handler != null && handler.shouldEnablePushKit(context)) {
      handler.onAppOpen(context);
    }
  }

  public boolean hasPushKitModule() {
    return handler != null;
  }
}

==> moengagesdk-4.1.02-sources.jar: com/moengage/push/hms/puskit/PushKitManager.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.push.hms.puskit;

import android.content.Context;
import android.support.annotation.NonNull;
import com.moengage.core.Logger;

/**
 * @author Umang Chamaria
 * Date: 08/04/20
 */
public class PushKitManager {

  private static final String TAG = "PushKitManager";

  PushKitHandler pushKitHandler;

  private PushKitManager() {
    loadHandler();
  }

  private static PushKitManager instance;

  public static PushKitManager getInstance() {
    if (instance == null) {
      synchronized (PushKitManager.class) {
        if (instance == null) instance = new PushKitManager();
      }
    }
    return instance;
  }

  private void loadHandler() {
    try {
      Class clazz = Class.forName("com.moengage.hms.pushkit.PushKitHandlerImpl");
      pushKitHandler = (PushKitHandler) clazz.newInstance();
    } catch (Exception e) {
      Logger.e(TAG + " PushKit module not present.");
    }
  }

  @SuppressWarnings("ConstantConditions")
  public void onAppOpen(@NonNull final Context context) {
    if (context == null || pushKitHandler == null )  return;

    pushKitHandler.onAppOpen(context);
  }

  public boolean hasPushKitModule() {
    return pushKitHandler != null;
  }
}
